@@ -2,9 +2,10 @@ package Method::Generate::DemolishAll;
 
 use Moo::_strictures;
 use Moo::Object ();
-our @ISA = qw(Moo::Object);
+BEGIN { our @ISA = qw(Moo::Object) }
 use Sub::Quote qw(quote_sub quotify);
 use Moo::_Utils qw(_getglob);
+use Moo::_mro;
 
 sub generate_method {
   my ($self, $into) = @_;
